@@ -45,7 +45,7 @@ class ThinkingSphinx::Middlewares::Inquirer <
 
     def call(raw_results, meta_results)
       context[:results] = raw_results.to_a
-      context[:raw]     = raw_results
+      context[:raw]     = context[:results].dup
       context[:meta]    = meta_results.inject({}) { |hash, row|
         hash[row['Variable_name']] = row['Value']
         hash
