@@ -14,10 +14,6 @@ class ThinkingSphinx::RealTime::Property
   end
 
   def translate(object)
-    return @column.__name unless @column.__name.is_a?(Symbol)
-
-    base = @column.__stack.inject(object) { |base, node| base.try(node) }
-    base = base.try(@column.__name)
-    base.is_a?(String) ? base.gsub("\u0000", '') : base
+    ThinkingSphinx::RealTime::Translator.call(object, @column)
   end
 end
